# Generated file. To retain edits, remove this comment.

"""itkwasm-htj2k: Wasm-SIMD accelerated decoding and encoding High-throughput JPEG2000 (HTJ2K) images."""

from .decode_async import decode_async
from .decode import decode
from .encode_async import encode_async
from .encode import encode

from ._version import __version__



from pathlib import Path
import itk
from itkwasm import Image
from itkwasm_compare_images import compare_images
import numpy as np

def encode_decode_roundtrip(file_path):
    from itkwasm_htj2k import encode, decode

    image = itk.imread(file_path)
    image_dict = itk.dict_from_image(image)
    image = Image(**image_dict)

    codestream = encode(image, decompositions=5, tile_size=[256, 256], block_dimensions=[64, 64])
    decoded_image = decode(codestream)

    metrics, _, _ = compare_images(image, baseline_images=[decoded_image,])
    assert metrics['almostEqual'] == True

def test_encode_decode_rgba():
    input_file = 'itk_logo.png'
    input_file_path = Path('..', '..', 'test', 'data', 'input', input_file)

    encode_decode_roundtrip(input_file_path)

def test_encode_decode_short():
    input_file = 'CT1.mha'
    input_file_path = Path('..', '..', 'test', 'data', 'input', input_file)

    encode_decode_roundtrip(input_file_path)



# Generated file. Do not edit.

import os
from typing import Dict, Tuple, Optional, List, Any

from itkwasm import (
    environment_dispatch,
    BinaryStream,
    Image,
)

async def decode_async(
    codestream: bytes,
    decomposition_level: int = 0,
    information_only: bool = False,
) -> Image:
    """Decode a High Throughput JPEG2000 codestream and generate an ITK Image

    :param codestream: Input HTJ2K codestream
    :type  codestream: bytes

    :param decomposition_level: Decomposition level to decode. 0 is the highest resolution.
    :type  decomposition_level: int

    :param information_only: Only read metadata for the image but do not decode the pixel data.
    :type  information_only: bool

    :return: Output image
    :rtype:  Image
    """
    func = environment_dispatch("itkwasm_htj2k", "decode_async")
    output = await func(codestream, decomposition_level=decomposition_level, information_only=information_only)
    return output



# Generated file. Do not edit.

import os
from typing import Dict, Tuple, Optional, List, Any

from itkwasm import (
    environment_dispatch,
    Image,
    BinaryStream,
)

def encode(
    image: Image,
    decompositions: int = 5,
    not_reversible: bool = False,
    quantization_step: float = 1,
    progression_order: int = 2,
    tile_size: List[int] = [512,512],
    tile_offset: List[int] = [0,0],
    block_dimensions: List[int] = [64,64],
) -> bytes:
    """Encode an ITK Image into a High Throughput JPEG2000 codestream

    :param image: Input image
    :type  image: Image

    :param decompositions: Number of wavelet decompositions
    :type  decompositions: int

    :param not_reversible: Lossy and not reversible, i.e. not lossless, encoding
    :type  not_reversible: bool

    :param quantization_step: Quantization step size for lossy compression. Ignored unless not reversible is enabled.
    :type  quantization_step: float

    :param progression_order: Progression order. 0 = LRCP, 1 = RLCP, 2 = RPCL, 3 = PCRL, 4 = CPRL
    :type  progression_order: int

    :param tile_size: Tile size
    :type  tile_size: int

    :param tile_offset: Tile offset
    :type  tile_offset: int

    :param block_dimensions: Block dimensions
    :type  block_dimensions: int

    :return: Output binary HTJ2K codestream
    :rtype:  bytes
    """
    func = environment_dispatch("itkwasm_htj2k", "encode")
    output = func(image, decompositions=decompositions, not_reversible=not_reversible, quantization_step=quantization_step, progression_order=progression_order, tile_size=tile_size, tile_offset=tile_offset, block_dimensions=block_dimensions)
    return output
